﻿using System;
using System.Collections.Generic;

namespace GuiBinConverter
{
    /// <summary>
    /// Вспомогательный класс, содержащий хелпер методы. В том числе и методы расширения.
    /// </summary>
    static class TradeHelper
    {

        #region Общие хелперы

        public static bool IsNull(this object obj)
        {
            return obj == null;
        }

        /// <summary>
        /// Метод упрощающий форматирование строк.
        /// </summary>
        /// <param name="str">Строка для форматирования.</param>
        /// <param name="args">Аргументы для форматирования.</param>
        /// <returns></returns>
        public static string Put(this string str, params object[] args)
        {
            return string.Format(str, args);
        }

        /// <summary>
        /// Сравнивает два значения double. Нужен для сравнения цен. Использует дельту 1Е-10
        /// Если разница между двумя значениями меньше дельты вернет истину.
        /// </summary>
        /// <param name="d1"></param>
        /// <param name="d2"></param>
        /// <returns></returns>
        public static bool IsPriceEqual(this double d1, double d2)
        {
            return Math.Abs(d1 - d2) < 1E-10;
        }

        #endregion

        #region Хелперы времени/даты

        /// <summary>
        /// Возвращает истину если время лежит в заданных границах, ВКЛЮЧИТЕЛЬНО!
        /// </summary>
        /// <param name="time">Время</param>
        /// <param name="minTime">Минимальная граница</param>
        /// <param name="maxTime">Максимальная граница</param>
        /// <returns></returns>
        public static bool InRange(this TimeSpan time, TimeSpan minTime, TimeSpan maxTime)
        {
            return time >= minTime && time <= maxTime;
        }

        #endregion
    }
}
